==================
gerrit-to-platform
==================

This is the documentation of **gerrit-to-platform**.

This documentation describes how to onboard a new project and troubleshooting
common issues.

Contents
========

.. toctree::
   :maxdepth: 2

   Overview <readme>

Guides
------

.. toctree::
   :maxdepth: 2

   onboard
   troubleshooting

Release and Coolaboration
-------------------------

.. toctree::
   :maxdepth: 2

   Contributions & Help <contributing>
   License <license>
   Authors <authors>
   Changelog <changelog>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _toctree: https://www.sphinx-doc.org/en/master/usage/restructuredtext/directives.html
